@@ -1,6 +1,5 @@
 #!/bin/bash
 # -*- shell-script -*-
-
 test_alias()
 {
     _Dbg_alias_add u up
@@ -17,7 +16,7 @@ test_alias()
 
     _Dbg_alias_add exit quit
     _Dbg_alias_find_aliased quit
-    assertEquals 'q, exit' "$aliases_found"
+    assertEquals 'exit, q' "$aliases_found"
 
     _Dbg_alias_remove q
     expanded_alias=''; _Dbg_alias_expand q
@@ -30,19 +29,15 @@ test_alias()
     assertEquals 'up' $expanded_alias
 }
 
-# Make sure ../.. has a trailing slash
-if [ '/src/external-vcs/bashdb-3.1' = '' ] ; then
+if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
   echo "Something is wrong: abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-vcs/bashdb-3.1
+abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+# Make sure $abs_top_srcr has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
-
+. ${abs_top_srcdir}test/unit/helper.sh
 . $abs_top_srcdir/lib/help.sh
 . $abs_top_srcdir/lib/alias.sh
-
-# load shunit2
-
-srcdir=.
-srcdir=${srcdir}/
-. ${srcdir}/shunit2
+set -- # reset $# so shunit2 doesn't get confused.
+[[ $0 == ${BASH_SOURCE} ]] && . ${shunit_file}
