@@ -1,6 +1,5 @@
 #!/bin/bash
 # -*- shell-script -*-
-
 test_sort()
 {
     do_one() {
@@ -31,11 +30,10 @@ test_sort()
     check=(1 2 3 4)
     do_one
     list=(' 4' '3 ' '2' '1')
-    if (( BASH_VERSINFO[0] > 4 || \
-	(BASH_VERSINFO[0] == 4 && BASH_VERSINFO[1] >= 1) )) ; then 
-	check=('1' '2' '3 ' ' 4')
-    else
+    if [[ ' 4' < '1' ]] ; then
 	check=(' 4' '1' '2' '3 ')
+    else
+	check=('1' '2' '3 ' ' 4')
     fi
     do_one
 
@@ -44,17 +42,15 @@ test_sort()
 }
 
 
-if [ '/src/external-vcs/bashdb' = '' ] ; then
+if [ '/src/external-vcs/sourceforge/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-vcs/bashdb
-# Make sure @abs_top_srcr@ has a trailing slash
+abs_top_srcdir=/src/external-vcs/sourceforge/bashdb
+# Make sure $abs_top_srcr has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
-
+. ${abs_top_srcdir}test/unit/helper.sh
 . $abs_top_srcdir/lib/sort.sh
+set -- # reset $# so shunit2 doesn't get confused.
 
-# load shunit2
-srcdir=.
-srcdir=${srcdir}/
-. ${srcdir}/shunit2
+[[ $0 == ${BASH_SOURCE} ]] && . ${shunit_file}
